@@ -784,7 +784,7 @@ BD_ANS_STATUS bd_ans_SetReportingMode(BOARD_PRIVATE_STRUCT *bps,
     IANS_BD_PARAM_EXT_SET_MODE *iANSreport;
     iANSreport = (IANS_BD_PARAM_EXT_SET_MODE *)ans_buffer;
 
-    printk("bd_ans_SetReportingMode: %d\n",
+    DEBUGLOG1("bd_ans_SetReportingMode: %d\n",
 	(iANSreport->BDIansStatusReport == IANS_REQUEST_SUPPORT));
     
     if (iANSreport->BDIansStatusReport == IANS_REQUEST_SUPPORT){
